#!/usr/bin/env python
# -*- coding: UTF-8 -*-

'''
    This program is free software; you can redistribute it and/or modify
    it under the terms of the Revised BSD License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Revised BSD License for more details.

    Copyright 2018-2026 Cool Dude 2k - http://idb.berlios.de/
    Copyright 2018-2026 Game Maker 2k - http://intdb.sourceforge.net/
    Copyright 2018-2026 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski

    $FileInfo: __init__.py - Last Update: 3/7/2026 Ver. 0.30.10 RC 1 - Author: cooldude2k $
'''

from .pyneofile import *
from . import pyneofile

__project__ = pyneofile.__project__
__program_name__ = pyneofile.__program_name__
__file_format_name__ = pyneofile.__file_format_name__
__file_format_magic__ = pyneofile.__file_format_magic__
__file_format_len__ = pyneofile.__file_format_len__
__file_format_hex__ = pyneofile.__file_format_hex__
__file_format_delimiter__ = pyneofile.__file_format_delimiter__
__file_format_dict__ = pyneofile.__file_format_dict__
__file_format_default__ = pyneofile.__file_format_default__
__file_format_multi_dict__ = pyneofile.__file_format_multi_dict__
__use_new_style__ = pyneofile.__use_new_style__
__use_advanced_list__ = pyneofile.__use_advanced_list__
__use_alt_inode__ = pyneofile.__use_alt_inode__
__project_url__ = pyneofile.__project_url__
__version_info__ = pyneofile.__version_info__
__version_date_info__ = pyneofile.__version_date_info__
__version_date__ = pyneofile.__version_date__
__version_date_plusrc__ = pyneofile.__version_date_plusrc__
__version__ = pyneofile.__version__
